@@ -11,17 +11,15 @@ class Similarity:
     def __init__(self):
         pass
 
-    def cosine_similarity(input_vec, concept_vec):
-        start_time = time.time()
-        similarity = sk.cosine_similarity(input_vec.transpose().todense(), concept_vec.transpose().todense())[0,0]
-        end_time = time.time()
-        return (similarity, end_time - start_time, 1)
+    def cosine_similarity(input_vec, concept_mat):
+        similarity = sk.cosine_similarity(input_vec.transpose().todense(), concept_mat.get_mat().transpose().todense())[0,:]
+
+        return similarity
         
 
     def maximum_matching_similarity(model, input_vec, concept_vec, input_terms, corpus_terms):
         s = model.similarity
         comparisons = 0
-        start_time = time.time()
         t1 = input_terms
         t2 = corpus_terms
         ind2 = concept_vec.indices
@@ -41,8 +39,8 @@ class Similarity:
                     continue
             similarity += (input_vec[i] * concept_vec[index])[0, 0] * max_similarity
         similarity /= norm(input_vec) * norm(concept_vec)
-        end_time = time.time()
-        return (similarity, end_time - start_time, comparisons)
+
+        return similarity
 
 
     def average_similarity(model, input_vec, concept_vec, input_terms, corpus_terms):
